sample_test_with_naarad_run_tests_in_parallel_20150203_185527

### sample_config1 : test1

Result | Function execution time | Total execution time
--- | --- | ---
Passed | 5.00542712212 sec | 5.03742384911 sec

Naarad report

### Metrics

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
sample-perf | latency | p99 lt 300.0 | None
sample-perf | latency | p50 lt 250.0 | None
sample-perf | latency | mean lt 125.0 | None
sample-perf | qps | mean lt 10.0 | None